arithmat: Sage implementation of arithmetic matroids and toric arrangements
===========================================================================

Description
-----------

Sage implementation of arithmetic matroids and toric arrangements

License
-------

GPLv3

Upstream Contact
----------------

https://pypi.org/project/arithmat/

